/**
 * A base class for HTTP errors.
 */
export declare class HttpError extends Error {
    readonly statusCode: number;
    /**
     * Creates an instance of HttpError.
     *
     * @param statusCode - The HTTP status code for the error.
     * @param [message] - The error message.
     */
    constructor(statusCode: number, message?: string);
}
/**
 * Represents a 400 Bad Request error.
 */
export declare class BadRequestError extends HttpError {
    /**
     * Creates an instance of BadRequestError.
     *
     * @param [message] - The error message.
     */
    constructor(message?: string);
}
/**
 * Represents a 401 Unauthenticated error.
 */
export declare class UnauthenticatedError extends HttpError {
    /**
     * Creates an instance of UnauthenticatedError.
     *
     * @param [message] - The error message.
     */
    constructor(message?: string);
}
/**
 * Represents a 403 Forbidden error.
 */
export declare class ForbiddenError extends HttpError {
    /**
     * Creates an instance of ForbiddenError.
     *
     * @param [message] - The error message.
     */
    constructor(message?: string);
}
/**
 * Represents a 404 Not Found error.
 */
export declare class NotFoundError extends HttpError {
    /**
     * Creates an instance of NotFoundError.
     *
     * @param [message] - The error message.
     */
    constructor(message?: string);
}
